@@ -17,7 +17,7 @@ class GitHub(object):
             owner_team=None,
             role_team=None,
             verbose=False,
-            debug_user=None,
+            app_project=None,
     ):
         """Initialize an GitHub class instance."""
         # set github token
@@ -42,8 +42,7 @@ class GitHub(object):
         # set the headers for authorized requests
         self.headers = {'Authorization': 'token {}'.format(self.token)}
 
-        # set a debug user dict that can be used by the App class
-        self.debug_user = debug_user
+        self.app_project = app_project
 
     #
     # Sub Classes
@@ -51,17 +50,24 @@ class GitHub(object):
     def app(self, auth=None):
         """Return an App instance."""
         from bits.github.app import App
-        return App(auth, self, debug_user=self.debug_user)
+        return App(auth=auth, github=self)
 
-    def client(self, auth=None):
+    def auditlogs(self, auth=None, args=None):
+        """Return an AuditLogs instance."""
+        from bits.github.auditlogs import AuditLogs
+        return AuditLogs(auth=auth, github=self, args=args)
+
+    def client(self, auth=None, app_project=None):
         """Return a Client instance."""
         from bits.github.client import Client
-        return Client(auth, self)
+        if not app_project:
+            app_project = self.app_project
+        return Client(auth=auth, github=self, app_project=app_project)
 
     def datastore(self, auth=None):
         """Return a Datastore instance."""
         from bits.github.datastore import Datastore
-        return Datastore(auth, self)
+        return Datastore(auth=auth, github=self)
 
     def firestore(
         self,
@@ -72,9 +78,11 @@ class GitHub(object):
     ):
         """Return a Firestore instance."""
         from bits.github.firestore import Firestore
+        if not app_project:
+            app_project = self.app_project
         return Firestore(
-            auth,
-            self,
+            auth=auth,
+            github=self,
             project=project,
             app_project=app_project,
             bitsdb_project=bitsdb_project,
@@ -83,17 +91,17 @@ class GitHub(object):
     def helpers(self, auth=None):
         """Return a Firestore instance."""
         from bits.github.helpers import Helpers
-        return Helpers(auth, self)
+        return Helpers(auth=auth, github=self)
 
     def sync(self, auth=None):
         """Return an Update instance."""
         from bits.github.sync import Sync
-        return Sync(auth, self)
+        return Sync(auth=auth, github=self)
 
     def update(self, auth=None):
         """Return an Update instance."""
         from bits.github.update import Update
-        return Update(auth, self)
+        return Update(auth=auth, github=self)
 
     #
     # Helpers
@@ -300,7 +308,9 @@ class GitHub(object):
         """Invite a member to the organization."""
         # PUT /orgs/:org/memberships/:username
         url = '{}/memberships/{}'.format(self.org_base_url, member)
-        return requests.put(url, headers=self.headers).json()
+        response = requests.put(url, headers=self.headers)
+        response.raise_for_status()
+        return response.json()
 
     def remove_org_member(self, member):
         """Delete an invitation to the organization."""
@@ -414,6 +424,15 @@ class GitHub(object):
     #
     # Repos
     #
+    def add_repo_collaborator(self, repo, username, permission='pull'):
+        """Add a user as a collaborator to a repo."""
+        # PUT /repos/:owner/:repo/collaborators/:username
+        url = '{}/repos/{}/{}/collaborators/{}'.format(self.base_url, self.org, repo, username)
+        params = {
+            'permission': permission,
+        }
+        return requests.put(url, headers=self.headers, params=params)
+
     def get_repo(self, repo, etag=None, last_modified=None):
         """Return a repo of the organization."""
         # GET /repos/:owner/:repo
@@ -491,17 +510,17 @@ class GitHub(object):
         """Return a dict of team members with children."""
         return self.get_dict(self.get_team_members_with_children(team_id, role), key)
 
-    def invite_team_member(self, team, member):
+    def invite_team_member(self, team_id, username):
         """Invite a member to the organization."""
         # PUT /teams/:id/memberships/:username
         params = {'role': 'member'}
-        url = '{}/teams/{}/memberships/{}'.format(self.base_url, team, member)
+        url = '{}/teams/{}/memberships/{}'.format(self.base_url, team_id, username)
         return requests.put(url, headers=self.headers, params=params)
 
-    def remove_team_member(self, team, member):
+    def remove_team_member(self, team_id, username):
         """Remove a member from the organization."""
         # DELETE /teams/:id/memberships/:username
-        url = '{}/teams/{}/memberships/{}'.format(self.base_url, team, member)
+        url = '{}/teams/{}/memberships/{}'.format(self.base_url, team_id, username)
         return requests.delete(url, headers=self.headers)
 
     def get_team_repos(self, team_id):
