@@ -271,6 +271,15 @@ class Update(object):
         invite = self._get_users_to_invite(current, new, invitations)
         remove = self._get_users_to_remove(current, new)
 
+        # check to make sure we do not remove too many members
+        current_count = len(current) + len(invitations)
+        new_count = len(new)
+
+        # check for more than 50 members being removed
+        if (current_count - new_count) > 50 or len(remove) > 50:
+            logging.error('More than 50 members to remove! Exiting.')
+            sys.exit(1)
+
         # check for invitations to cancel
         logins = self._get_new_logins(new)
         uninvite = self._get_users_to_uninvite(invitations, logins)
